@@ -52,6 +52,8 @@ def is_fsspec_asset(asset: pystac.Asset) -> bool:
     Determine if an Asset points to an fsspec URL.
 
     This checks if "account_name" is present in the asset's "table:storage_options"
-    field.
+    or "xarray:storage_options" fields.
     """
-    return "account_name" in asset.extra_fields.get("table:storage_options", {})
+    return "account_name" in asset.extra_fields.get(
+        "table:storage_options", {}
+    ) or "account_name" in asset.extra_fields.get("xarray:storage_options", {})
